<?php

namespace Alive\Dm;

use UnexpectedValueException;

/**
 * Template rendering helper.
 */
class Template {

    private $template;
    private $params;

    /**
     * Parameters for the template.
     * @param string $tempalate Template name or templates string.
     * @param array $params Array of parameters that can be used durong rendering phase.
     */
    public function __construct($template, $params = array()) {
        $this->template = $template;
        $this->params = $params;
    }

    /**
     * Get full template filename.
     * @param string $template Full path to the template.
     */
    private function get_template_filename($template) {
        // FIXME: Tohle je fujtajbl.
        $filename = dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' .DIRECTORY_SEPARATOR  . 'templates' . DIRECTORY_SEPARATOR . $template;
        if (!file_exists($filename)) {
            throw new UnexpectedValueException("Template file '$template' does not exist.");
        }
        return $filename;
    }

    /**
     * Build the template.
     * @return string Built template.
     */
    public function build() {
        // XXX: Tohle je zjednodušení. Není to zrovna dvakrát bezpečné, ale pro tyto účely dostačující.
        foreach ($this->params as $name => $value) {
            $this->{$name} = $value;
        }
        ob_start();
            $template_filename = $this->get_template_filename($this->template);
            include $template_filename;
        return ob_get_clean();
    }

    /**
     * HTML escape provided string.
     * @param string $value Value to be escaped.
     */
    public function escape($value) {
        return esc_html($value);
    }

    /**
     * Translate given string.
     * @param string $message Message to be trenalated.
     */
    public function translate($message) {
        return __($message, 'alive-sport');
    }
}
